@@ -17,11 +17,15 @@ from deepdriver.sdk.interface import interface
 @util.login_required
 def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Dict = None) -> Run:
     """ # 실행과 실험환경을 만드는 함수 """
-    # team_name 변수 vailidation
-    if team_name:
+    # exp_name 변수 vailidation
+    if exp_name:
         pattern = re.compile('[^a-zA-Z0-9._]+')
         if pattern.findall(exp_name):
-            logger.info("init() failed : team_name은 숫자(number), 영문자(alphabet), 언더바(_), 온점(.)만 가능합니다.")
+            logger.info("init() failed : exp_name은 숫자(number), 영문자(alphabet), 언더바(_), 온점(.)만 가능합니다.")
+            return None
+
+        if len(exp_name) >= 50:
+            logger.info("init() failed :  exp_name의 최대 길이는 50자 미만입니다. [max length 50]")
             return None
 
     rsp = interface.init(exp_name, team_name, run_name, config)
